Examples — beampy 0.0.1.4 documentation

# Examples

beampy.examples code.

List of examples from the beampy.examples module.

`beampy.examples.` `example_free_propag`()

  Show the free propagation of a beam (no refractive index variation) and confirm that Beampy return the correct waist value

`beampy.examples.` `example_gaussian_beam`()

  Display a Gaussian beam with the fwhm definition.

`beampy.examples.` `example_guides_x`()

  Display a Gaussian guide, two super-Gaussian guides and a flat-top guide to illustrate the width definition.

`beampy.examples.` `example_guides_z`()

  Display an array of guides and the curved guides system.

`beampy.examples.` `example_kerr`()

  More test than example. Show the different approximation possible for the BPM implementation of the Kerr effect.

`beampy.examples.` `example_stability`()

  Show the possible BPM approximations for implementing a refractive index variation

`Gaussian beam definition`

`Guide definition over x`

`Array of guides`

`Curved guides`

`Example with field real part`

`Example with field imag part`

`Example with power`

`Example with Kerr`

`Example with extreme Kerr`